@@ -1,9 +1,8 @@
 import cv2
 import numpy as np
-import logging
 import torch
 import torch.nn as nn
-from torchvision import models, transforms
+from torchvision import models
 import torchvision.transforms.functional as TF
 import os
 
